<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/gcomp_geom.php';
require_once 'lib/gcomp_margins.php';

class GCompsFactory
{
    public static function do_get_geom_def($w, $h, $role, $align_def)
    {
        return array(
            GCompGeometryDef::w => $w,
            GCompGeometryDef::h => $h,
            GCompGeometryDef::role => $role,

            GCompGeometryDef::align_def => $align_def,
        );
    }

    public static function get_role_geom_def($w, $h, $role)
    {
        return self::do_get_geom_def($w, $h, $role, null);
    }

    public static function get_align_def($x=0, $y=0,
        $use_base_width=null, $use_base_height=null,
        $halign=null, $valign=null, $base_halign=null, $base_valign=null,
        $base_to_prev=false, $base_id=null)
    {
        return array(
            GCompAlignDef::x => $x,
            GCompAlignDef::y => $y,
            GCompAlignDef::use_base_width => $use_base_width,
            GCompAlignDef::use_base_height => $use_base_height,
            GCompAlignDef::halign => $halign,
            GCompAlignDef::valign => $valign,
            GCompAlignDef::base_halign => $base_halign,
            GCompAlignDef::base_valign => $base_valign,
            GCompAlignDef::base_to_prev => $base_to_prev,
            GCompAlignDef::base_id => $base_id,
        );
    }

    // TODO: legacy
    public static function get_geom_def($x, $y, $w, $h,
        $halign=null, $valign=null, $base_halign=null, $base_valign=null,
        $base_to_prev=false, $base_id=null)
    {
        return self::do_get_geom_def($w, $h, null,
            self::get_align_def($x, $y, null, null, 
                $halign, $valign, $base_halign, $base_valign, $base_to_prev, $base_id));
    }

    public static function get_label_def($geom, $margins,
        $text, $max_num_lines=1, $color=15, $font_size=FONT_SIZE_NORMAL, $id=null)
    {
        return array(
            GComponentDef::id => $id,
            GComponentDef::geom_def => $geom,
            GComponentDef::margins_def => $margins,
            GComponentDef::kind => GCOMPONENT_LABEL,
            GComponentDef::specific_def =>
                array(
                    GCompLabelDef::text => $text,
                    GCompLabelDef::max_num_lines => $max_num_lines,
                    GCompLabelDef::text_color => $color,
                    GCompLabelDef::font_size => $font_size,
                ),
        );
    }

    public static function get_ttf_label_def($geom, $margins,
        $text, $max_num_lines=1, $color="#FFFFFFE0", $font_size=36, $id=null)
    {
        return array(
            GComponentDef::id => $id,
            GComponentDef::geom_def => $geom,
            GComponentDef::margins_def => $margins,
            GComponentDef::kind => GCOMPONENT_TTF_LABEL,
            GComponentDef::specific_def =>
                array(
                    GCompLabelDef::text => $text,
                    GCompLabelDef::max_num_lines => $max_num_lines,
                    GCompLabelDef::text_color => $color,
                    GCompLabelDef::font_size => $font_size,
                ),
        );
    }

    public static function get_rect_def($geom, $margins, $color)
    {
        return array(
            GComponentDef::geom_def => $geom,
            GComponentDef::margins_def => $margins,
            GComponentDef::kind => GCOMPONENT_RECT,
            GComponentDef::specific_def =>
                array(
                    GCompRectDef::color => $color,
                ),
        );
    }

    public static function get_image_def($geom, $margins, $url,
        $keep_aspect_ratio=false, $upscale_enabled=true,
        $not_loaded_url=null, $low_quality_url=null)
    {
        return array(
            GComponentDef::geom_def => $geom,
            GComponentDef::margins_def => $margins,
            GComponentDef::kind => GCOMPONENT_IMAGE,
            GComponentDef::specific_def =>
                array(
                    GCompImageDef::url => $url,
                    GCompImageDef::keep_aspect_ratio => $keep_aspect_ratio,
                    GCompImageDef::upscale_enabled => $upscale_enabled,
                    GCompImageDef::not_loaded_url => $not_loaded_url,
                    GCompImageDef::low_quality_url => $low_quality_url,
                ),
        );
    }

    public static function get_cut_image_def($id,
        $geom, $margins, $url)
    {
        return array(
            GComponentDef::id => $id,
            GComponentDef::geom_def => $geom,
            GComponentDef::margins_def => $margins,
            GComponentDef::kind => GCOMPONENT_CUT_IMAGE,
            GComponentDef::specific_def =>
                array(
                    GCompImageDef::url => $url,
                ),
        );
    }

    public static function get_button_def($id, 
        $geom, $margins, $caption, $selected=false, $caption_centered=true)
    {
        return array(
            GComponentDef::id => $id,
            GComponentDef::geom_def => $geom,
            GComponentDef::margins_def => $margins,
            GComponentDef::kind => GCOMPONENT_BUTTON,
            GComponentDef::specific_def =>
                array(
                    GCompButtonDef::caption => $caption,
                    GCompButtonDef::selected => $selected,
                    GCompButtonDef::caption_centered => $caption_centered,
                ),
        );
    }

    public static function get_scrollbar_def($geom, $margins, 
        $scroll_pane_id, $vertical=true)
    {
        return array(
            GComponentDef::geom_def => $geom,
            GComponentDef::margins_def => $margins,
            GComponentDef::kind => GCOMPONENT_SCROLLBAR,
            GComponentDef::specific_def =>
                array(
                    GCompScrollbarDef::scroll_pane_id => $scroll_pane_id,
                    GCompScrollbarDef::vertical => $vertical,
                ),
        );
    }

    public static function get_view_position_def($x, $y, $id=null)
    {
        return array(
            GCompViewPositionDef::x => $x,
            GCompViewPositionDef::y => $y,
            GCompViewPositionDef::id => $id);
    }

    public static function get_panel_def($id, 
        $geom, $margins, $children)
    {
        return array(
            GComponentDef::id => $id,
            GComponentDef::geom_def => $geom,
            GComponentDef::margins_def => $margins,
            GComponentDef::kind => GCOMPONENT_PANEL,
            GComponentDef::specific_def =>
                array(
                    GCompPanelDef::children => $children,
                ),
        );
    }

    public static function get_ppane_def($id, $geom,
        $children, $native_width=0, $native_height=0)
    {
        return array(
            GComponentDef::id => $id,
            GComponentDef::geom_def => $geom,
            GComponentDef::kind => GCOMPONENT_PREPAINT_PANE,
            GComponentDef::specific_def =>
                array(
                    GCompPrepaintPaneDef::panel => 
                        array(GCompPanelDef::children => $children),
                    GCompPrepaintPaneDef::native_width => $native_width,
                    GCompPrepaintPaneDef::native_height => $native_height,
                ),
        );
    }

    public static function get_spane_def($id, $geom, $margins,
        $children, $view_width=0, $view_height=0, $view_position=null)
    {
        return array(
            GComponentDef::id => $id,
            GComponentDef::geom_def => $geom,
            GComponentDef::margins_def => $margins,
            GComponentDef::kind => GCOMPONENT_SCROLL_PANE,
            GComponentDef::specific_def =>
                array(
                    GCompScrollPaneDef::panel =>
                        array(GCompPanelDef::children => $children),
                    GCompScrollPaneDef::view_width => $view_width,
                    GCompScrollPaneDef::view_height => $view_height,
                    GCompScrollPaneDef::view_position => $view_position,
                ),
        );
    }

    public static function get_vertical_spane_def($id, $geom, $margins,
        $children, $view_position=null)
    {
        return array(
            GComponentDef::id => $id,
            GComponentDef::geom_def => $geom,
            GComponentDef::margins_def => $margins,
            GComponentDef::kind => GCOMPONENT_SCROLL_PANE,
            GComponentDef::specific_def =>
                array(
                    GCompScrollPaneDef::panel =>
                        array(GCompPanelDef::children => $children),
                    GCompScrollPaneDef::view_use_base_width => true,
                    GCompScrollPaneDef::view_position => $view_position,
                ),
        );
    }

    public static function get_horizontal_spane_def($id, $geom, $margins,
        $children, $view_position=null)
    {
        return array(
            GComponentDef::id => $id,
            GComponentDef::geom_def => $geom,
            GComponentDef::margins_def => $margins,
            GComponentDef::kind => GCOMPONENT_SCROLL_PANE,
            GComponentDef::specific_def =>
                array(
                    GCompScrollPaneDef::panel =>
                        array(GCompPanelDef::children => $children),
                    GCompScrollPaneDef::view_use_base_height => true,
                    GCompScrollPaneDef::view_position => $view_position,
                ),
        );
    }

    public static function get_window_def($comp_defs, $background_url=null,
        $background_color=null,
        $not_loaded_background_url=null,
        $async_loading_background=false,
        $playback_bg_alpha=-1)
    {
        return array(
            GCompWindowDef::background_color => $background_color,
            GCompWindowDef::background_url => $background_url,
            GCompWindowDef::async_loading_background => $async_loading_background,
            GCompWindowDef::comp_defs => $comp_defs,
            GCompWindowDef::not_loaded_background_url => $not_loaded_background_url,
            GCompWindowDef::playback_bg_alpha => $playback_bg_alpha);
    }

    ////////////////////////////////////////////////////////////

    public static function get_change_def($id, $geom, $props=null,
        $view_position=null, $selected=null, $children=null,
        $transition=GCOMP_TRANSITION_DEFAULT)
    {
        return array(
            ChangeGCompDef::id => $id,
            ChangeGCompDef::geom_def => $geom,
            ChangeGCompDef::props => $props,
            ChangeGCompDef::view_position => $view_position,
            ChangeGCompDef::selected => $selected,
            ChangeGCompDef::children => $children,
            ChangeGCompDef::transition => $transition,
        );
    }
}

?>
