<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/abstract_controls_screen.php';

require_once 'zwave_status.php';

class RootScreen extends AbstractControlsScreen
{
    const ID = 'Root';

    private /* ZwaveControllerPlugin */ $plugin;
    private /* ZwaveStatus */ $zwave_status;

    private $last_defs = array();

    public static function get_media_url_str()
    {
        return self::ID;
    }

    public function __construct(ZwaveControllerPlugin $plugin)
    {
        $this->plugin = $plugin;
        $this->zwave_status = new ZwaveStatus();
        parent::__construct(self::ID);
    }

    public function get_control_defs(MediaURL $media_url, &$plugin_cookies)
    {
        $defs = array();

        if (!$this->zwave_status->app_is_running())
        {
            if ($this->zwave_status->no_module_flag_set())
            {
                $this->add_label($defs, null, T::t("label_controller_status_no_module"));
                $this->add_vgap($defs, 20);
                $this->add_label($defs, null, T::t("label_controller_no_module_msg1"));
                $this->add_label($defs, null, T::t("label_controller_no_module_msg2"));
            }
            else
            {
                $this->add_label($defs, null, T::t("label_controller_status_not_running"));
            }
            return $defs;
        }

        $this->add_label($defs, null, T::t("label_controller_status_running"));
        $this->add_vgap($defs, -15);

        $device_count = $this->zwave_status->get_device_count();
        if ($device_count >= 0)
            $device_count_text = "%ext%<key_local>label_device_count__1<p>$device_count</p></key_local>";
        else
            $device_count_text = T::t("label_device_count_detecting");
        $this->add_label($defs, null, $device_count_text);
        $this->add_vgap($defs, -15);

        $user_id = '';
        if ($this->zwave_status->remote_access_is_allowed())
        {
            $user_id = $this->zwave_status->get_user_id();
            if ($user_id != '')
                $remote_access_text = "%ext%<key_local>label_internet_access_id__1<p>$user_id</p></key_local>";
            else
                $remote_access_text = T::t("label_internet_access_id_unknown");
        }
        else
        {
            $remote_access_text = T::t("label_internet_access_disabled");
        }
        $this->add_label($defs, null, $remote_access_text);

        $this->add_vgap($defs, 20);

        $this->add_label($defs, null, T::t("label_usage_instructions"));

        $this->add_vgap($defs, 20);

        $this->add_label($defs, null, T::t("label_web_app"));
        $this->add_vgap($defs, -15);
        $this->add_label($defs, null, T::t("label_web_app_local"));

        if ($user_id != '')
        {
            $this->add_vgap($defs, -15);

            $user_name = $this->zwave_status->get_user_name();
            if ($user_name == '')
            {
                // We use default user name in ZWave in this case.
                $user_name = 'admin';
            }
            $login = "$user_id/$user_name";
            $web_app_internet_text = "%ext%<key_local>label_web_app_internet__1<p>$login</p></key_local>";
            $this->add_label($defs, null, $web_app_internet_text);
        }

        $this->add_vgap($defs, 20);

        $this->add_label($defs, null, T::t("label_android_app"));
        $this->add_vgap($defs, -15);
        $this->add_label($defs, null, T::t("label_ios_app"));

        $this->add_vgap($defs, 20);

        $this->add_label($defs, null, T::t("label_beta_version"));

        return $defs;
    }

    protected function get_timer($media_url)
    {
        return ActionFactory::timer(1000);
    }

    protected function get_action_map($media_url)
    {
        $timer_action = UserInputHandlerRegistry::create_action($this, 'timeout');

        return array(
            GUI_EVENT_TIMER => $timer_action,
        );
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        $post_action = null;
        $control_id = isset($user_input->control_id) ?
            $user_input->control_id : "none";

        $media_url = MediaUrl::decode(self::ID);

        if ($control_id === 'timeout')
        {
            $post_action = ActionFactory::change_behaviour(
                $this->get_action_map($media_url),
                $this->get_timer($media_url));
        }

        $defs = $this->get_control_defs($media_url, $plugin_cookies);
        if ($defs == $this->last_defs)
            return $post_action;

        $this->last_defs = $defs;
        return ActionFactory::reset_controls($defs, $post_action);
    }

}

///////////////////////////////////////////////////////////////////////////
?>
