<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/utils.php';

class ZwaveStatus
{
    const ZWAVE_PLUGIN_TMP_DIR = '/tmp/plugins/zwave_controller';
    const ZWAVE_CONFIG_PATH = '/config/rs/zwave';
    const ZWAY_SERVER_PROCESS = 'z-way-server';
    const ZWAY_SERVER_ADDRESS = 'http://127.0.0.1:8083';

    private $zwave_no_module_flag_path;
    private $zbw_config_path;
    private $zbw_flag_no_connection_filename;
    private $zbw_user_id_filename;
    private $zway_get_device_count_url;

    private $plugin_dir;
    private $get_credentials_script;
    private $curl_executable;

    private $credentials;
    private $user_name;

    private function update_credentials()
    {
        $this->credentials = trim(exec($this->get_credentials_script));
        $this->user_name = '';
        $pos = strpos($this->credentials, ':');
        if ($pos !== false)
            $this->user_name = substr($this->credentials, 0, $pos);
    }

    public function __construct()
    {
        $this->zwave_no_module_flag_path = self::ZWAVE_PLUGIN_TMP_DIR . '/no_module.flag';
        $this->zbw_config_path = self::ZWAVE_CONFIG_PATH . '/zbw';
        $this->zbw_flag_no_connection_filename = $this->zbw_config_path . '/flags/no_connection';
        $this->zbw_user_id_filename = $this->zbw_config_path . '/userid';
        $this->zway_get_device_count_url = self::ZWAY_SERVER_ADDRESS . '/ZWaveAPI/Run/devices.length';

        $this->plugin_dir = DuneSystem::$properties['install_dir_path'];
        $this->get_credentials_script = $this->plugin_dir . '/bin/get_credentials.sh';
        $this->curl_executable = $this->plugin_dir . '/bin/curl.875x';

        $this->update_credentials();
    }

    private function process_zwave_request($request_url)
    {
        $this->update_credentials();
        $exec_str = $this->curl_executable . ' -kL -s -u ' .
            '"' . $this->credentials . '" ' .
            '"' . $request_url . '"';

        return trim(exec($exec_str));
    }

    public function app_is_running()
    {
        $process_name = "z-way-server";
        $pid = exec('pidof ' . self::ZWAY_SERVER_PROCESS);
        return ($pid != '');
    }

    public function no_module_flag_set()
    {
        return file_exists($this->zwave_no_module_flag_path);
    }

    public function get_device_count()
    {
        $request_result = $this->process_zwave_request($this->zway_get_device_count_url);
        if ($request_result == '404 Not Found')
            return -1;

        $device_count = $request_result;
        if (!$device_count || $device_count <= 0)
            return -1;

        // We exclude Zwave device chip in Dune itself.
        return $device_count - 1;
    }

    public function remote_access_is_allowed()
    {
        return !file_exists($this->zbw_flag_no_connection_filename);
    }

    public function get_user_id()
    {
        if (!file_exists($this->zbw_user_id_filename))
            return '';

        return trim(@file_get_contents($this->zbw_user_id_filename));
    }

    public function get_user_name()
    {
        return $this->user_name;
    }
}

///////////////////////////////////////////////////////////////////////////
?>
